@@ -37,6 +37,7 @@ sub new {
                              $self->Option('nocompact'),  # 5 %nocompact
                              $self->Option('lexerisdefined'),    # 6 lexer is defined
                              $self->Option('prefix'),            # 7 accept prefix
+                             $self->Option('start'),            # 8 specify start symbol
                              #$self->Option('prefixname'),  # yyprefix
                              #$self->Option('buildingtree')  # If building AST
                             );
@@ -226,17 +227,22 @@ sub classname {
 sub Rules { # TODO: find proper names
     my($self)=shift;
     my($rules)=$$self{GRAMMAR}{RULES};
-    my($text) = "[\n";
+    my($text) = "[#[productionNameAndLabel => lhs, [ rhs], bypass]]\n";
     my $packages = q{'TERMINAL', '_OPTIONAL', '_STAR_LIST', '_PLUS_LIST', };
 
     my $index = 0;
+    my $label = "{\n"; # To huild a reverse map label => production number
     for (@$rules) {
         my($lhs,$rhs,$prec,$name)=@$_;
 
         my $bypass = $name->[2];
         $bypass = $self->Bypass unless defined($bypass);
+
+        $label .= "  '$1' => $index,\n" if defined($name->[0]) and $name->[0] =~ /(:.*)/;
+
         # find an acceptable perl identifier as name
         $name = $self->classname($name, $index, $lhs, $rhs);
+        $label .= "  '$name' => $index,\n";
 
         $packages .= "\n".(" "x9)."'$name', ";
 
@@ -246,7 +252,8 @@ sub Rules { # TODO: find proper names
         $index++;
     }
     $text .= ']';
-    return ($text, $packages);
+    $label .= '}';
+    return ($text, $packages, $label);
 }
 
 # Added by Casiano
@@ -326,6 +333,9 @@ sub Accessors {
 ###########################
 sub Warnings {
     my($self)=shift;
+
+    return '' unless $self->{OPTIONS}{star};
+
     my($text) = '';
     my($grammar)=$$self{GRAMMAR};
 
